==> plasma-pa-5.13.5.tar.xz: plasma-pa-5.13.5/src/port.h <==
/*
    Copyright 2014-2015 Harald Sitter <sitter@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PORT_H
#define PORT_H

#include "profile.h"

#include <pulse/def.h>

namespace QPulseAudio
{

class Port : public Profile
{
    Q_OBJECT

public:

    Port(QObject *parent);
    virtual ~Port();

    template<typename PAInfo>
    void setInfo(const PAInfo *info)
    {
        Availability newAvailability;
        switch (info->available) {
        case PA_PORT_AVAILABLE_NO:
            newAvailability = Unavailable;
            break;
        case PA_PORT_AVAILABLE_YES:
            newAvailability = Available;
            break;
        default:
            newAvailability = Unknown;
        }
        setCommonInfo(info, newAvailability);
    }
};

} // QPulseAudio

#endif // PORT_H

==> plasma-pa_5.18.4.1.orig.tar.xz: plasma-pa-5.18.4.1/src/port.h <==
/*
    Copyright 2014-2015 Harald Sitter <sitter@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PORT_H
#define PORT_H

#include "profile.h"

#include <pulse/def.h>

namespace QPulseAudio
{

class Port : public Profile
{
    Q_OBJECT

public:

    explicit Port(QObject *parent);
    ~Port() override;

    template<typename PAInfo>
    void setInfo(const PAInfo *info)
    {
        Availability newAvailability;
        switch (info->available) {
        case PA_PORT_AVAILABLE_NO:
            newAvailability = Unavailable;
            break;
        case PA_PORT_AVAILABLE_YES:
            newAvailability = Available;
            break;
        default:
            newAvailability = Unknown;
        }
        setCommonInfo(info, newAvailability);
    }
};

} // QPulseAudio

#endif // PORT_H
